@@ -33,7 +33,5 @@ config = dict(
     # It is also used by the git-hook, for the same reason.
     # It is also used by the mediawiki php plugin which, due to the oddities of
     # php, can't maintain a single passive-bind endpoint of it's own.
-    relay_inbound=[
-        "tcp://127.0.0.1:2003",
-    ],
+    relay_inbound="tcp://127.0.0.1:2003",
 )
