@@ -19,13 +19,20 @@
 #
 """ Federated Message Bus Client API """
 
-import inspect
 import threading
 import functools
 
 import fedmsg.core
 import fedmsg.config
 
+# The python3.11 doesn't have getargspec anymore
+# getarcspec is deprecated till python 3.0
+# Let's try to first import one otherwise the other
+try:
+    from inspect import getfullargspec as inspect_getargs
+except ImportError:
+    from inspect import getargspec as inspect_getargs
+
 __local = threading.local()
 
 __all__ = [
@@ -64,7 +71,7 @@ def init(**kw):
 
 def API_function(doc=None):
     def api_function(func):
-        scrub = inspect.getfullargspec(func).args
+        scrub = inspect_getargs(func).args
 
         @functools.wraps(func)
         def _wrapper(*args, **kw):
@@ -76,7 +83,7 @@ def API_function(doc=None):
                         del config_overrides[arg]
 
                 init(**config_overrides)
-                assert(__local.__context)
+                assert __local.__context
 
             return func(*args, **kw)
 
