@@ -21,7 +21,11 @@
 import os
 import unittest
 
-import mock
+# In Python 3 the mock is part of unittest
+try:
+    import mock
+except ImportError:
+    from unittest import mock
 
 import fedmsg.config
 from fedmsg.tests.base import FIXTURES_DIR
@@ -234,6 +238,7 @@ class FedmsgConfigTests(unittest.TestCase):
         'stomp_ssl_crt': None,
         'stomp_ssl_key': None,
         'datagrepper_url': None,
+        'skip_last_message': False,
     }
 
     def test_defaults(self):
